"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chalk = require('chalk');
var fs = require('fs');
var path = require('path');
var printHowToInstallCorrectly = function () {
    console.log();
    console.log('You can create a valid SpringType app in this folder using:');
    console.log();
    console.log('    npx st-create-app my-app');
    console.log();
};
exports.validateIsSpringTypeProject = function () {
    var coreDependency = '@springtype/core';
    var projectPackageJsonFile = path.resolve(path.join(process.cwd(), 'package.json'));
    if (!fs.existsSync(projectPackageJsonFile)) {
        console.error(chalk.red("This project doesn't look like a SpringType project because " + projectPackageJsonFile + " is missing.\n"));
        printHowToInstallCorrectly();
        process.exit(1);
    }
    var projectPackageJson = require(projectPackageJsonFile);
    if (!projectPackageJson.dependencies || !projectPackageJson.dependencies[coreDependency]) {
        console.error(chalk.red("This project (package.json) doesn't look like a SpringType project because the dependency " + chalk.green(coreDependency) + " is missing.\n"));
        printHowToInstallCorrectly();
        process.exit(1);
    }
};
//# sourceMappingURL=validateIsSpringTypeProject.js.map